@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -54,14 +54,12 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
     /**
      * Used to build output as hex.
      */
-    private static final char[] DIGITS_LOWER = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-            'e', 'f' };
+    private static final char[] DIGITS_LOWER = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f' };
 
     /**
      * Used to build output as hex.
      */
-    private static final char[] DIGITS_UPPER = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D',
-            'E', 'F' };
+    private static final char[] DIGITS_UPPER = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };
 
     /**
      * Converts an array of characters representing hexadecimal values into an array of bytes of those same values. The
@@ -92,25 +90,21 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      */
     public static int decodeHex(final char[] data, final byte[] out, final int outOffset) throws DecoderException {
         final int len = data.length;
-
         if ((len & 0x01) != 0) {
             throw new DecoderException("Odd number of characters.");
         }
-
         final int outLen = len >> 1;
         if (out.length - outOffset < outLen) {
             throw new DecoderException("Output array is not large enough to accommodate decoded data.");
         }
-
         // two characters form the hex value.
         for (int i = outOffset, j = 0; j < len; i++) {
             int f = toDigit(data[j], j) << 4;
             j++;
-            f = f | toDigit(data[j], j);
+            f |= toDigit(data[j], j);
             j++;
             out[i] = (byte) (f & 0xFF);
         }
-
         return outLen;
     }
 
@@ -123,7 +117,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * @return A byte array containing binary data decoded from the supplied char array.
      * @throws DecoderException Thrown if an odd number of characters or illegal characters are supplied
      * @since 1.11
-     */ 
+     */
     public static byte[] decodeHex(final String data) throws DecoderException {
         return decodeHex(data.toCharArray());
     }
@@ -133,7 +127,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * The returned array will be double the length of the passed array, as it takes two characters to represent any
      * given byte.
      *
-     * @param data a byte[] to convert to hex characters
+     * @param data a byte[] to convert to hexadecimal characters
      * @return A char[] containing lower-case hexadecimal characters
      */
     public static char[] encodeHex(final byte[] data) {
@@ -151,7 +145,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * @since 1.4
      */
     public static char[] encodeHex(final byte[] data, final boolean toLowerCase) {
-        return encodeHex(data, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER);
+        return encodeHex(data, toAlphabet(toLowerCase));
     }
 
     /**
@@ -159,23 +153,21 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * The returned array will be double the length of the passed array, as it takes two characters to represent any
      * given byte.
      *
-     * @param data     a byte[] to convert to hex characters
+     * @param data     a byte[] to convert to hexadecimal characters
      * @param toDigits the output alphabet (must contain at least 16 chars)
      * @return A char[] containing the appropriate characters from the alphabet For best results, this should be either
      *         upper- or lower-case hex.
      * @since 1.4
      */
     protected static char[] encodeHex(final byte[] data, final char[] toDigits) {
-        final int l = data.length;
-        final char[] out = new char[l << 1];
-        encodeHex(data, 0, data.length, toDigits, out, 0);
-        return out;
+        final int dataLength = data.length;
+        return encodeHex(data, 0, dataLength, toDigits, new char[dataLength << 1], 0);
     }
 
     /**
      * Converts an array of bytes into an array of characters representing the hexadecimal values of each byte in order.
      *
-     * @param data a byte[] to convert to hex characters
+     * @param data a byte[] to convert to hexadecimal characters
      * @param dataOffset the position in {@code data} to start encoding from
      * @param dataLen the number of bytes from {@code dataOffset} to encode
      * @param toLowerCase {@code true} converts to lowercase, {@code false} to uppercase
@@ -183,17 +175,14 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      *         upper- or lower-case hex.
      * @since 1.15
      */
-    public static char[] encodeHex(final byte[] data, final int dataOffset, final int dataLen,
-            final boolean toLowerCase) {
-        final char[] out = new char[dataLen << 1];
-        encodeHex(data, dataOffset, dataLen, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER, out, 0);
-        return out;
+    public static char[] encodeHex(final byte[] data, final int dataOffset, final int dataLen, final boolean toLowerCase) {
+        return encodeHex(data, dataOffset, dataLen, toAlphabet(toLowerCase), new char[dataLen << 1], 0);
     }
 
     /**
      * Converts an array of bytes into an array of characters representing the hexadecimal values of each byte in order.
      *
-     * @param data a byte[] to convert to hex characters
+     * @param data a byte[] to convert to hexadecimal characters
      * @param dataOffset the position in {@code data} to start encoding from
      * @param dataLen the number of bytes from {@code dataOffset} to encode
      * @param toLowerCase {@code true} converts to lowercase, {@code false} to uppercase
@@ -201,28 +190,28 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * @param outOffset the position within {@code out} at which to start writing the encoded characters.
      * @since 1.15
      */
-    public static void encodeHex(final byte[] data, final int dataOffset, final int dataLen,
-            final boolean toLowerCase, final char[] out, final int outOffset) {
-        encodeHex(data, dataOffset, dataLen, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER, out, outOffset);
+    public static void encodeHex(final byte[] data, final int dataOffset, final int dataLen, final boolean toLowerCase, final char[] out, final int outOffset) {
+        encodeHex(data, dataOffset, dataLen, toAlphabet(toLowerCase), out, outOffset);
     }
 
     /**
      * Converts an array of bytes into an array of characters representing the hexadecimal values of each byte in order.
      *
-     * @param data a byte[] to convert to hex characters
+     * @param data a byte[] to convert to hexadecimal characters
      * @param dataOffset the position in {@code data} to start encoding from
      * @param dataLen the number of bytes from {@code dataOffset} to encode
      * @param toDigits the output alphabet (must contain at least 16 chars)
      * @param out a char[] which will hold the resultant appropriate characters from the alphabet.
      * @param outOffset the position within {@code out} at which to start writing the encoded characters.
+     * @return the given {@code out}.
      */
-    private static void encodeHex(final byte[] data, final int dataOffset, final int dataLen, final char[] toDigits,
-            final char[] out, final int outOffset) {
+    private static char[] encodeHex(final byte[] data, final int dataOffset, final int dataLen, final char[] toDigits, final char[] out, final int outOffset) {
         // two characters form the hex value.
         for (int i = dataOffset, j = outOffset; i < dataOffset + dataLen; i++) {
             out[j++] = toDigits[(0xF0 & data[i]) >>> 4];
             out[j++] = toDigits[0x0F & data[i]];
         }
+        return out;
     }
 
     /**
@@ -233,7 +222,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param data a byte buffer to convert to hex characters
+     * @param data a byte buffer to convert to hexadecimal characters
      * @return A char[] containing lower-case hexadecimal characters
      * @since 1.11
      */
@@ -249,13 +238,13 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param data        a byte buffer to convert to hex characters
+     * @param data        a byte buffer to convert to hexadecimal characters
      * @param toLowerCase {@code true} converts to lowercase, {@code false} to uppercase
      * @return A char[] containing hexadecimal characters in the selected case
      * @since 1.11
      */
     public static char[] encodeHex(final ByteBuffer data, final boolean toLowerCase) {
-        return encodeHex(data, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER);
+        return encodeHex(data, toAlphabet(toLowerCase));
     }
 
     /**
@@ -266,7 +255,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param byteBuffer a byte buffer to convert to hex characters
+     * @param byteBuffer a byte buffer to convert to hexadecimal characters
      * @param toDigits   the output alphabet (must be at least 16 characters)
      * @return A char[] containing the appropriate characters from the alphabet For best results, this should be either
      *         upper- or lower-case hex.
@@ -280,7 +269,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * Converts an array of bytes into a String representing the hexadecimal values of each byte in order. The returned
      * String will be double the length of the passed array, as it takes two characters to represent any given byte.
      *
-     * @param data a byte[] to convert to hex characters
+     * @param data a byte[] to convert to hexadecimal characters
      * @return A String containing lower-case hexadecimal characters
      * @since 1.4
      */
@@ -292,7 +281,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * Converts an array of bytes into a String representing the hexadecimal values of each byte in order. The returned
      * String will be double the length of the passed array, as it takes two characters to represent any given byte.
      *
-     * @param data        a byte[] to convert to hex characters
+     * @param data        a byte[] to convert to hexadecimal characters
      * @param toLowerCase {@code true} converts to lowercase, {@code false} to uppercase
      * @return A String containing lower-case hexadecimal characters
      * @since 1.11
@@ -308,7 +297,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param data a byte buffer to convert to hex characters
+     * @param data a byte buffer to convert to hexadecimal characters
      * @return A String containing lower-case hexadecimal characters
      * @since 1.11
      */
@@ -323,7 +312,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param data        a byte buffer to convert to hex characters
+     * @param data        a byte buffer to convert to hexadecimal characters
      * @param toLowerCase {@code true} converts to lowercase, {@code false} to uppercase
      * @return A String containing lower-case hexadecimal characters
      * @since 1.11
@@ -332,6 +321,16 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
         return new String(encodeHex(data, toLowerCase));
     }
 
+    /**
+     * Converts a boolean to an alphabet.
+     *
+     * @param toLowerCase true for lowercase, false for uppercase.
+     * @return an alphabet.
+     */
+    private static char[] toAlphabet(final boolean toLowerCase) {
+        return toLowerCase ? DIGITS_LOWER : DIGITS_UPPER;
+    }
+
     /**
      * Convert the byte buffer to a byte array. All bytes identified by
      * {@link ByteBuffer#remaining()} will be used.
@@ -361,7 +360,7 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * @param ch    A character to convert to an integer digit
      * @param index The index of the character in the source
      * @return An integer
-     * @throws DecoderException Thrown if ch is an illegal hex character
+     * @throws DecoderException Thrown if ch is an illegal hexadecimal character
      */
     protected static int toDigit(final char ch, final int index) throws DecoderException {
         final int digit = Character.digit(ch, 16);
@@ -451,16 +450,17 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
     public Object decode(final Object object) throws DecoderException {
         if (object instanceof String) {
             return decode(((String) object).toCharArray());
-        } else if (object instanceof byte[]) {
+        }
+        if (object instanceof byte[]) {
             return decode((byte[]) object);
-        } else if (object instanceof ByteBuffer) {
+        }
+        if (object instanceof ByteBuffer) {
             return decode((ByteBuffer) object);
-        } else {
-            try {
-                return decodeHex((char[]) object);
-            } catch (final ClassCastException e) {
-                throw new DecoderException(e.getMessage(), e);
-            }
+        }
+        try {
+            return decodeHex((char[]) object);
+        } catch (final ClassCastException e) {
+            throw new DecoderException(e.getMessage(), e);
         }
     }
 
@@ -473,14 +473,14 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * {@link #getCharset()}.
      * </p>
      *
-     * @param array a byte[] to convert to hex characters
+     * @param array a byte[] to convert to hexadecimal characters
      * @return A byte[] containing the bytes of the lower-case hexadecimal characters
      * @since 1.7 No longer throws IllegalStateException if the charsetName is invalid.
      * @see #encodeHex(byte[])
      */
     @Override
     public byte[] encode(final byte[] array) {
-        return encodeHexString(array).getBytes(this.getCharset());
+        return encodeHexString(array).getBytes(getCharset());
     }
 
     /**
@@ -494,13 +494,13 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * <p>All bytes identified by {@link ByteBuffer#remaining()} will be used; after this method
      * the value {@link ByteBuffer#remaining() remaining()} will be zero.</p>
      *
-     * @param array a byte buffer to convert to hex characters
+     * @param array a byte buffer to convert to hexadecimal characters
      * @return A byte[] containing the bytes of the lower-case hexadecimal characters
      * @see #encodeHex(byte[])
      * @since 1.11
      */
     public byte[] encode(final ByteBuffer array) {
-        return encodeHexString(array).getBytes(this.getCharset());
+        return encodeHexString(array).getBytes(getCharset());
     }
 
     /**
@@ -512,16 +512,16 @@ public class Hex implements BinaryEncoder, BinaryDecoder {
      * {@link #getCharset()}.
      * </p>
      *
-     * @param object a String, ByteBuffer, or byte[] to convert to hex characters
+     * @param object a String, ByteBuffer, or byte[] to convert to hexadecimal characters
      * @return A char[] containing lower-case hexadecimal characters
      * @throws EncoderException Thrown if the given object is not a String or byte[]
      * @see #encodeHex(byte[])
      */
     @Override
     public Object encode(final Object object) throws EncoderException {
-        byte[] byteArray;
+        final byte[] byteArray;
         if (object instanceof String) {
-            byteArray = ((String) object).getBytes(this.getCharset());
+            byteArray = ((String) object).getBytes(getCharset());
         } else if (object instanceof ByteBuffer) {
             byteArray = toByteArray((ByteBuffer) object);
         } else {
