@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,9 +22,9 @@ import java.util.Arrays;
 import java.util.regex.Pattern;
 
 /**
- * UNIX crypt(3) algorithm implementation.
+ * Unix crypt(3) algorithm implementation.
  * <p>
- * This class only implements the traditional 56 bit DES based algorithm. Please use DigestUtils.crypt() for a method
+ * This class only implements the traditional 56 bit DES based algorithm. Please use Crypt.crypt() for a method
  * that distinguishes between all the algorithms supported in the current glibc's crypt().
  * </p>
  * <p>
@@ -56,9 +56,6 @@ public class UnixCrypt {
             71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102,
             103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122 };
 
-    private static final char[] SALT_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./"
-            .toCharArray();
-
     private static final boolean[] SHIFT2 = { false, false, true, true, true, true, true, true, false, true, true,
             true, true, true, true, false };
 
@@ -243,17 +240,14 @@ public class UnixCrypt {
      *            plaintext password
      * @param salt
      *            a two character string drawn from [a-zA-Z0-9./]. The salt may be null, in which case a salt is
-     *            generated for you using {@link SecureRandom}.
+     *            generated for you using {@link B64#getRandomSalt(int)}.
      * @return a 13 character string starting with the salt string
      * @throws IllegalArgumentException
      *             if the salt does not match the allowed pattern
      */
     public static String crypt(final byte[] original, String salt) {
         if (salt == null) {
-            final SecureRandom randomGenerator = new SecureRandom();
-            final int numSaltChars = SALT_CHARS.length;
-            salt = "" + SALT_CHARS[randomGenerator.nextInt(numSaltChars)] +
-                    SALT_CHARS[randomGenerator.nextInt(numSaltChars)];
+            salt = B64.getRandomSalt(2);
         } else if (!CRYPT_SALT_PATTERN.matcher(salt).matches()) {
             throw new IllegalArgumentException("Invalid salt value: " + salt);
         }
