@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,7 +30,7 @@ import org.apache.commons.codec.StringEncoder;
  * Phonetic) algorithm issued by Hans Joachim Postel in 1969.
  * </p>
  * <p>
- * The <i>K&ouml;lner Phonetik</i> is a phonetic algorithm which is optimized for the German language. It is related to
+ * The <em>K&ouml;lner Phonetik</em> is a phonetic algorithm which is optimized for the German language. It is related to
  * the well-known soundex algorithm.
  * </p>
  *
@@ -193,12 +193,12 @@ public class ColognePhonetic implements StringEncoder {
 
         protected int length;
 
-        public CologneBuffer(final char[] data) {
+        CologneBuffer(final char[] data) {
             this.data = data;
             this.length = data.length;
         }
 
-        public CologneBuffer(final int buffSize) {
+        CologneBuffer(final int buffSize) {
             this.data = new char[buffSize];
             this.length = 0;
         }
@@ -218,9 +218,10 @@ public class ColognePhonetic implements StringEncoder {
             return new String(copyData(0, length));
         }
     }
+
     private final class CologneInputBuffer extends CologneBuffer {
 
-        public CologneInputBuffer(final char[] data) {
+        CologneInputBuffer(final char[] data) {
             super(data);
         }
 
@@ -245,11 +246,12 @@ public class ColognePhonetic implements StringEncoder {
             return ch;
         }
     }
+
     private final class CologneOutputBuffer extends CologneBuffer {
 
         private char lastCode;
 
-        public CologneOutputBuffer(final int buffSize) {
+        CologneOutputBuffer(final int buffSize) {
             super(buffSize);
             lastCode = '/'; // impossible value
         }
@@ -303,16 +305,23 @@ public class ColognePhonetic implements StringEncoder {
         return false;
     }
 
+    /**
+     * Constructs a new instance.
+     */
+    public ColognePhonetic() {
+        // empty
+    }
+
     /**
      * <p>
-     * Implements the <i>K&ouml;lner Phonetik</i> algorithm.
+     * Implements the <em>K&ouml;lner Phonetik</em> algorithm.
      * </p>
      * <p>
      * In contrast to the initial description of the algorithm, this implementation does the encoding in one pass.
      * </p>
      *
      * @param text The source text to encode
-     * @return the corresponding encoding according to the <i>K&ouml;lner Phonetik</i> algorithm
+     * @return the corresponding encoding according to the <em>K&ouml;lner Phonetik</em> algorithm
      */
     public String colognePhonetic(final String text) {
         if (text == null) {
