@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -281,7 +281,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      *            the buffer to write to
      * @return The number of bytes written to the {@code buffer}
      */
-    private static final int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
+    private static int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
         buffer.write(ESCAPE_CHAR);
         final char hex1 = Utils.hexDigit(b >> 4);
         final char hex2 = Utils.hexDigit(b);
