@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -29,7 +29,6 @@ import java.io.InputStream;
 import org.junit.jupiter.api.Test;
 
 /**
- * @since 1.15
  */
 public class Base16InputStreamTest {
 
@@ -48,7 +47,7 @@ public class Base16InputStreamTest {
     @Test
     public void testAvailable() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             assertEquals(1, b16Stream.available());
             assertEquals(6, b16Stream.skip(10));
             // End of stream reached
@@ -75,8 +74,7 @@ public class Base16InputStreamTest {
     /**
      * Tests the Base16InputStream implementation.
      *
-     * @throws IOException
-     *             for some failure scenarios.
+     * @throws IOException for some failure scenarios.
      */
     @Test
     public void testBase16InputStreamByChunk() throws IOException {
@@ -141,8 +139,7 @@ public class Base16InputStreamTest {
      * Tests method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]--> encoded 3. decoded
      * ---[WRAP-WRAP-WRAP-etc...] --> decoded
      * <p/>
-     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over
-     * again.
+     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over again.
      *
      * @param encoded Base16 encoded data
      * @param decoded the data from above, but decoded
@@ -156,18 +153,17 @@ public class Base16InputStreamTest {
      * Tests method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]--> encoded 3. decoded
      * ---[WRAP-WRAP-WRAP-etc...] --> decoded
      * <p/>
-     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over
-     * again.
+     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over again.
      *
-     * @param encoded Base16 encoded data
-     * @param decoded the data from above, but decoded
+     * @param encoded   Base16 encoded data
+     * @param decoded   the data from above, but decoded
      * @param lowerCase if {@code true} then use a lower-case Base16 alphabet
      * @throws IOException Usually signifies a bug in the Base16 commons-codec implementation.
      */
     private void testByChunk(final byte[] encoded, final byte[] decoded, final boolean lowerCase) throws IOException {
 
         // Start with encode.
-        try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(decoded), true, lowerCase)) {
+        try (InputStream in = new Base16InputStream(new ByteArrayInputStream(decoded), true, lowerCase)) {
             final byte[] output = BaseNTestData.streamToBytes(in);
 
             assertEquals(-1, in.read(), "EOF");
@@ -176,7 +172,7 @@ public class Base16InputStreamTest {
         }
 
         // Now let's try to decode.
-        try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
+        try (InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
             final byte[] output = BaseNTestData.streamToBytes(in);
 
             assertEquals(-1, in.read(), "EOF");
@@ -185,9 +181,9 @@ public class Base16InputStreamTest {
         }
 
         // wrap encoder with decoder
-        try (final InputStream in = new ByteArrayInputStream(decoded);
-                final InputStream inEncode = new Base16InputStream(in, true, lowerCase);
-                final InputStream inDecode = new Base16InputStream(inEncode, false, lowerCase)) {
+        try (InputStream in = new ByteArrayInputStream(decoded);
+                InputStream inEncode = new Base16InputStream(in, true, lowerCase);
+                InputStream inDecode = new Base16InputStream(inEncode, false, lowerCase)) {
 
             final byte[] output = BaseNTestData.streamToBytes(inDecode);
 
@@ -201,8 +197,7 @@ public class Base16InputStreamTest {
      * Tests method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]--> encoded 3. decoded
      * ---[WRAP-WRAP-WRAP-etc...] --> decoded
      * <p/>
-     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over
-     * again.
+     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over again.
      *
      * @param encoded Base16 encoded data
      * @param decoded the data from above, but decoded
@@ -216,18 +211,17 @@ public class Base16InputStreamTest {
      * Tests method does three tests on the supplied data: 1. encoded ---[DECODE]--> decoded 2. decoded ---[ENCODE]--> encoded 3. decoded
      * ---[WRAP-WRAP-WRAP-etc...] --> decoded
      * <p/>
-     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over
-     * again.
+     * By "[WRAP-WRAP-WRAP-etc...]" we mean situation where the Base16InputStream wraps itself in encode and decode mode over and over again.
      *
-     * @param encoded Base16 encoded data
-     * @param decoded the data from above, but decoded
+     * @param encoded   Base16 encoded data
+     * @param decoded   the data from above, but decoded
      * @param lowerCase if {@code true} then use a lower-case Base16 alphabet
      * @throws IOException Usually signifies a bug in the Base16 commons-codec implementation.
      */
     private void testByteByByte(final byte[] encoded, final byte[] decoded, final boolean lowerCase) throws IOException {
 
         // Start with encode.
-        try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(decoded), true, lowerCase)) {
+        try (InputStream in = new Base16InputStream(new ByteArrayInputStream(decoded), true, lowerCase)) {
             final byte[] output = new byte[encoded.length];
             for (int i = 0; i < output.length; i++) {
                 output[i] = (byte) in.read();
@@ -239,7 +233,7 @@ public class Base16InputStreamTest {
         }
 
         // Now let's try to decode.
-        try (final InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
+        try (InputStream in = new Base16InputStream(new ByteArrayInputStream(encoded), false, lowerCase)) {
             final byte[] output = new byte[decoded.length];
             for (int i = 0; i < output.length; i++) {
                 output[i] = (byte) in.read();
@@ -251,9 +245,9 @@ public class Base16InputStreamTest {
         }
 
         // wrap encoder with decoder
-        try (final InputStream in = new ByteArrayInputStream(decoded);
-                final InputStream inEncode = new Base16InputStream(in, true, lowerCase);
-                final InputStream inDecode = new Base16InputStream(inEncode, false, lowerCase)) {
+        try (InputStream in = new ByteArrayInputStream(decoded);
+                InputStream inEncode = new Base16InputStream(in, true, lowerCase);
+                InputStream inDecode = new Base16InputStream(inEncode, false, lowerCase)) {
 
             final byte[] output = new byte[decoded.length];
             for (int i = 0; i < output.length; i++) {
@@ -275,7 +269,7 @@ public class Base16InputStreamTest {
     public void testMarkSupported() throws IOException {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base16InputStream in = new Base16InputStream(bin, true)) {
+        try (Base16InputStream in = new Base16InputStream(bin, true)) {
             // Always returns false for now.
             assertFalse(in.markSupported(), "Base16InputStream.markSupported() is false");
         }
@@ -292,7 +286,7 @@ public class Base16InputStreamTest {
         final byte[] buf = new byte[1024];
         int bytesRead = 0;
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base16InputStream in = new Base16InputStream(bin, true)) {
+        try (Base16InputStream in = new Base16InputStream(bin, true)) {
             bytesRead = in.read(buf, 0, 0);
             assertEquals(0, bytesRead, "Base16InputStream.read(buf, 0, 0) returns 0");
         }
@@ -307,9 +301,8 @@ public class Base16InputStreamTest {
     public void testReadNull() throws IOException {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base16InputStream in = new Base16InputStream(bin, true)) {
-            assertThrows(NullPointerException.class, () -> in.read(null, 0, 0),
-                "Base16InputStream.read(null, 0, 0)");
+        try (Base16InputStream in = new Base16InputStream(bin, true)) {
+            assertThrows(NullPointerException.class, () -> in.read(null, 0, 0), "Base16InputStream.read(null, 0, 0)");
         }
     }
 
@@ -323,7 +316,7 @@ public class Base16InputStreamTest {
         final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
         final byte[] buf = new byte[1024];
         final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base16InputStream in = new Base16InputStream(bin, true)) {
+        try (Base16InputStream in = new Base16InputStream(bin, true)) {
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, -1, 0), "Base16InputStream.read(buf, -1, 0)");
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, 0, -1), "Base16InputStream.read(buf, 0, -1)");
             assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length + 1, 0), "Base16InputStream.read(buf, buf.length + 1, 0)");
@@ -339,7 +332,7 @@ public class Base16InputStreamTest {
     @Test
     public void testSkipBig() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             assertEquals(6, b16Stream.skip(Integer.MAX_VALUE));
             // End of stream reached
             assertEquals(-1, b16Stream.read());
@@ -355,11 +348,11 @@ public class Base16InputStreamTest {
     @Test
     public void testSkipNone() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             final byte[] actualBytes = new byte[6];
             assertEquals(0, b16Stream.skip(0));
             b16Stream.read(actualBytes, 0, actualBytes.length);
-            assertArrayEquals(actualBytes, new byte[] {(byte)202, (byte)254, (byte)186, (byte)190, (byte)255, (byte)255});
+            assertArrayEquals(actualBytes, new byte[] { (byte) 202, (byte) 254, (byte) 186, (byte) 190, (byte) 255, (byte) 255 });
             // End of stream reached
             assertEquals(-1, b16Stream.read());
         }
@@ -373,7 +366,7 @@ public class Base16InputStreamTest {
     @Test
     public void testSkipPastEnd() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
             assertEquals(6, b16Stream.skip(10));
             // End of stream reached
@@ -390,7 +383,7 @@ public class Base16InputStreamTest {
     @Test
     public void testSkipToEnd() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
             assertEquals(6, b16Stream.skip(6));
             // End of stream reached
@@ -407,7 +400,7 @@ public class Base16InputStreamTest {
     @Test
     public void testSkipWrongArgument() throws IOException {
         final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_B16));
-        try (final Base16InputStream b16Stream = new Base16InputStream(ins)) {
+        try (Base16InputStream b16Stream = new Base16InputStream(ins)) {
             assertThrows(IllegalArgumentException.class, () -> b16Stream.skip(-10));
         }
     }
