@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -292,6 +292,22 @@ public class Base32Test {
     @Test
     public void testBase32HexImpossibleSamples() {
         testImpossibleCases(new Base32(0, null, true, BaseNCodec.PAD_DEFAULT, CodecPolicy.STRICT), BASE32HEX_IMPOSSIBLE_CASES);
+        // @formatter:off
+        testImpossibleCases(Base32.builder()
+                .setHexEncodeTable(true)
+                .setDecodingPolicy(CodecPolicy.STRICT)
+                .get(), BASE32HEX_IMPOSSIBLE_CASES);
+        // @formatter:on
+        // overrides, last set wins
+        // @formatter:off
+        testImpossibleCases(Base32.builder()
+                .setHexDecodeTable(false)
+                .setHexDecodeTable(true)
+                .setHexEncodeTable(false)
+                .setHexEncodeTable(true)
+                .setDecodingPolicy(CodecPolicy.STRICT)
+                .get(), BASE32HEX_IMPOSSIBLE_CASES);
+        // @formatter:on
     }
 
     @Test
