@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -44,7 +44,7 @@ public class HexTest {
 
     private static final String BAD_ENCODING_NAME = "UNKNOWN";
 
-    private final static boolean LOG = false;
+    private static final boolean LOG = false;
 
     /**
      * Allocate a ByteBuffer.
