@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,16 +20,14 @@ package org.apache.commons.codec.language;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import org.apache.commons.codec.AbstractStringEncoderTest;
 import org.apache.commons.codec.EncoderException;
-import org.apache.commons.codec.StringEncoderAbstractTest;
 import org.junit.jupiter.api.Test;
 
 /**
  * Tests Caverphone1.
- *
- * @since 1.5
  */
-public class Caverphone1Test extends StringEncoderAbstractTest<Caverphone1> {
+public class Caverphone1Test extends AbstractStringEncoderTest<Caverphone1> {
 
     @Override
     protected Caverphone1 createStringEncoder() {
@@ -37,7 +35,7 @@ public class Caverphone1Test extends StringEncoderAbstractTest<Caverphone1> {
     }
 
     /**
-     * Tests example adapted from version 2.0  http://caversham.otago.ac.nz/files/working/ctp150804.pdf
+     * Tests example adapted from version 2.0  https://caversham.otago.ac.nz/files/working/ctp150804.pdf
      *
      * AT1111 words: add, aid, at, art, eat, earth, head, hit, hot, hold, hard, heart, it, out, old
      *
@@ -45,7 +43,7 @@ public class Caverphone1Test extends StringEncoderAbstractTest<Caverphone1> {
      */
     @Test
     public void testCaverphoneRevisitedCommonCodeAT1111() throws EncoderException {
-        this.checkEncodingVariations("AT1111", new String[]{
+        checkEncodingVariations("AT1111", new String[]{
             "add",
             "aid",
             "at",
@@ -66,11 +64,11 @@ public class Caverphone1Test extends StringEncoderAbstractTest<Caverphone1> {
     @Test
     public void testEndMb() throws EncoderException {
         final String[][] data = {{"mb", "M11111"}, {"mbmb", "MPM111"}};
-        this.checkEncodings(data);
+        checkEncodings(data);
     }
 
     /**
-     * Tests some examples from version 2.0 http://caversham.otago.ac.nz/files/working/ctp150804.pdf
+     * Tests some examples from version 2.0 https://caversham.otago.ac.nz/files/working/ctp150804.pdf
      *
      * @throws EncoderException for some failure scenarios.
      */
@@ -82,25 +80,25 @@ public class Caverphone1Test extends StringEncoderAbstractTest<Caverphone1> {
     }
 
     /**
-     * Tests example from http://caversham.otago.ac.nz/files/working/ctp060902.pdf
+     * Tests example from https://caversham.otago.ac.nz/files/working/ctp060902.pdf
      *
      * @throws EncoderException for some failure scenarios.
      */
     @Test
     public void testSpecificationV1Examples() throws EncoderException {
         final String[][] data = {{"David", "TFT111"}, {"Whittle", "WTL111"}};
-        this.checkEncodings(data);
+        checkEncodings(data);
     }
 
     /**
-     * Tests examples from http://en.wikipedia.org/wiki/Caverphone
+     * Tests examples from https://en.wikipedia.org/wiki/Caverphone
      *
      * @throws EncoderException for some failure scenarios.
      */
     @Test
     public void testWikipediaExamples() throws EncoderException {
         final String[][] data = {{"Lee", "L11111"}, {"Thompson", "TMPSN1"}};
-        this.checkEncodings(data);
+        checkEncodings(data);
     }
 
 }
